@@ -22,7 +22,8 @@ die "Couldn't create new Excel file: $!.\n" unless defined $workbook;
 my $worksheet = $workbook->add_worksheet();
 my $bold      = $workbook->add_format(bold =>  1);
 
-$worksheet->set_column('A:B', 30);
+$worksheet->set_column('A:A', 20);
+$worksheet->set_column('B:B', 15);
 
 
 # Some example date and time formats
@@ -38,28 +39,28 @@ my $format9   = $workbook->add_format(num_format => 'dd/mm/yy'    );
 
 
 # Write some explanatory labels
-$worksheet->write_date_time('A1', '"General Date" format', $bold);
-$worksheet->write_date_time('A2', '"Short Date" format',   $bold);
-$worksheet->write_date_time('A3', '"Medium Date" format',  $bold);
-$worksheet->write_date_time('A4', '"Long Date" format',    $bold);
-$worksheet->write_date_time('A5', '"Short Time" format',   $bold);
-$worksheet->write_date_time('A6', '"Medium Time" format',  $bold);
-$worksheet->write_date_time('A7', '"Long Time" format',    $bold);
-$worksheet->write_date_time('A8', '"mm/dd/yy" format',     $bold);
-$worksheet->write_date_time('A9', '"dd/mm/yy" format',     $bold);
-
+$worksheet->write_date_time('A1',  'Date format', $bold);
+$worksheet->write_date_time('A2',  '"General Date"'    );
+$worksheet->write_date_time('A3',  '"Short Date"'      );
+$worksheet->write_date_time('A4',  '"Medium Date"'     );
+$worksheet->write_date_time('A5',  '"Long Date"'       );
+$worksheet->write_date_time('A6',  '"Short Time"'      );
+$worksheet->write_date_time('A7',  '"Medium Time"'     );
+$worksheet->write_date_time('A8',  '"Long Time"'       );
+$worksheet->write_date_time('A9',  '"mm/dd/yy"'        );
+$worksheet->write_date_time('A10', '"dd/mm/yy"'        );
 
 # Write the same date with different formatting
-$worksheet->write_date_time('B1', '2004-05-11T23:20', $format1);
-$worksheet->write_date_time('B2', '2004-05-11T23:20', $format2);
-$worksheet->write_date_time('B3', '2004-05-11T23:20', $format3);
-$worksheet->write_date_time('B4', '2004-05-11T23:20', $format4);
-$worksheet->write_date_time('B5', '2004-05-11T23:20', $format5);
-$worksheet->write_date_time('B6', '2004-05-11T23:20', $format6);
-$worksheet->write_date_time('B7', '2004-05-11T23:20', $format7);
-$worksheet->write_date_time('B8', '2004-05-11T23:20', $format8);
-$worksheet->write_date_time('B9', '2004-05-11T23:20', $format9);
-
+$worksheet->write_date_time('B1',  'Formatted date',   $bold   );
+$worksheet->write_date_time('B2',  '2004-05-13T23:20', $format1);
+$worksheet->write_date_time('B3',  '2004-05-13T23:20', $format2);
+$worksheet->write_date_time('B4',  '2004-05-13T23:20', $format3);
+$worksheet->write_date_time('B5',  '2004-05-13T23:20', $format4);
+$worksheet->write_date_time('B6',  '2004-05-13T23:20', $format5);
+$worksheet->write_date_time('B7',  '2004-05-13T23:20', $format6);
+$worksheet->write_date_time('B8',  '2004-05-13T23:20', $format7);
+$worksheet->write_date_time('B9',  '2004-05-13T23:20', $format8);
+$worksheet->write_date_time('B10', '2004-05-13T23:20', $format9);
 
 __END__
 
